@@ -2,12 +2,7 @@ class Sponsees:
     _url_path = "/partner/sponsees"
 
     def __init__(
-        self,
-        sponsorship_code,
-        sponsees_max,
-        sponsees_number,
-        sponsees,
-        **kwargs
+        self, sponsorship_code, sponsees_max, sponsees_number, sponsees, **kwargs
     ):
         self.sponsorship_code = sponsorship_code
         self.sponsees_max = sponsees_max
