@@ -17,21 +17,15 @@ class DiscoveryChannelTests(unittest.TestCase):
             channel_names.append(dc.name)
 
         # Default lang is catalan
-        self.assertIn(
-            "Fires / Xerrades",
-            channel_names
-        )
+        self.assertIn("Fires / Xerrades", channel_names)
 
     @pytest.mark.vcr()
     def test_search_language_spanish(self):
-        discovery_channels = DiscoveryChannel.search(lang='es')
+        discovery_channels = DiscoveryChannel.search(lang="es")
         channel_names = []
         self.assertEqual(len(discovery_channels), 8)
         for dc in discovery_channels:
             self.assertIsInstance(dc, DiscoveryChannel)
             channel_names.append(dc.name)
 
-        self.assertIn(
-            "Ferias / Charlas",
-            channel_names
-        )
+        self.assertIn("Ferias / Charlas", channel_names)
